import matplotlib as mpl
import matplotlib.pyplot as plt

def draw_vertical_cross_section_1FIG(VER,FigTitle,colormap,clevels,args,\
                                     draw_top,draw_bottom,\
                                     UVALONG="N",WVER="N",maxUV=0,scaleUV=0):

    Fxsiz = 8
    Fysiz = 7
    shrink_v = 0.6
    
    fig = plt.figure(figsize=(Fxsiz,Fysiz))

    # configure for a single figure in the whole figure domain
    ax  = fig.add_subplot(111)    
    
    # limit draw range
    if(draw_top > draw_bottom + 0.01):
        VER = VER.sel(LEV=slice(draw_bottom,draw_top))
        if args.WIND is not None:
            WVER = WVER.sel(LEV=slice(draw_bottom,draw_top))
            UVALONG = UVALONG.sel(LEV=slice(draw_bottom,draw_top))

    contourf = ax.contourf(VER["DISTANCE"],VER["LEV"],VER,\
                           cmap=colormap,levels=clevels,extend="both")
    
    plt.colorbar(contourf,shrink=shrink_v, pad= 0.03)

    if args.WIND is not None:
       if int(args.WIND) == 0:  # vector
            Q=ax.quiver(WVER["DISTANCE"].values,WVER["LEV"].values,\
                        UVALONG,WVER,\
                        units='inches',scale=scaleUV)
            X1 = Fxsiz *0.8
            Y1 = Fysiz *0.9
            ax.quiverkey(Q,X1,Y1,maxUV,str(maxUV)+"m/s",
                         labelpos='E',coordinates='inches')
            
    # setting for xlabel and ylabel
    ax.set_xlabel("distance (km)", size=14)
    ax.set_ylabel("altitude (m)", size=14)
            
    # Draw Fig Title
    ax.set_title(FigTitle,loc="center")         

    if args.OUTFIG is not None:
        plt.savefig(args.OUTFIG)
    
    plt.show()
